io.github.evenmoreirrelevance.testcomments.core


-bind-itcljmacro

(-bind-it form & body)
source

-introduced-bindingsclj

(-introduced-bindings form)
source

-potential-map-bindingsclj

(-potential-map-bindings subform)
source

-xp-test-commentclj

(-xp-test-comment test-name [form-head & comment-forms :as wrapped-form])
source

bindcljmacro

(bind definition & forms)

Binds the output of forms to the given vars, returning it. Is evaluated in a test-comment context.

Binds the output of `forms` to the given vars, returning it. 
Is evaluated in a `test-comment` context.
sourceraw docstring

effectcljmacro

(effect & forms)

Evaluates forms for a side effect, also in a test-comment context.

Evaluates `forms` for a side effect, also in a `test-comment` context.
sourceraw docstring

expand-in-test-commentcljmultimethod

Expands the form in a test-comment context, dispatching on the symbolic representation of the head if it resolves to a var.

Note that if no var is resolved, the form is simply ignored.

Also note that expansion isn't to a fixpoint like with macros; to trigger another expansion, you must call expand-in-test-comment manually, and to propagate the expansion to subforms you'll need to use expand-test-comment-forms.

Expands the form in a `test-comment` context,
dispatching on the symbolic representation of the head
if it resolves to a var.

Note that if no var is resolved, the form is simply ignored.

Also note that expansion isn't to a fixpoint like with macros;
to trigger another expansion, you must call `expand-in-test-comment` manually, 
and to propagate the expansion to subforms you'll need to use `expand-test-comment-forms`.
sourceraw docstring

expand-test-comment-formsclj

(expand-test-comment-forms forms)

Expands forms in a test-comment context, discarding nil expansions. Returns nil if no form expands into anything meaningful.

Expands `forms` in a `test-comment` context, discarding `nil` expansions.
Returns `nil` if no form expands into anything meaningful.
sourceraw docstring

remove-all-tests!clj

(remove-all-tests!)
(remove-all-tests! the-ns)

Removes all tests in the namespace, defaulting to *ns*.

Removes all tests in the namespace, defaulting to `*ns*`.
sourceraw docstring

test--introduced-bindingsclj

source

test-commentcljmacro

(test-comment test-name [form-head & comment-forms :as wrapped-form])

Wraps a comment form, expanding into a deftest with the given test-name.

Wraps a `comment` form, expanding into a `deftest` with the given `test-name`.
sourceraw docstring

test-test-commentclj

source

test-xp-test-comment-contentclj

source

valuecljmacro

(value form & body)

Like values but anaphorically binds to it, and returns the single value bound to :value rather than a :values map.

Errors out if it is already bound.

Like `values` but anaphorically binds to `it`, and returns the single value bound to `:value`
rather than a `:values` map.

Errors out if `it` is already bound.
sourceraw docstring

value=cljmacro

(value= form equal)
source

valuescljmacro

(values [& bindings] & body)

Behaves like a let, but returns a map where :result is bound to the value of the last form in body, and :values is bound to a map from the symbols in the left hand sides of the bindings to their value.

In a test-comment context, behaves like a let that evaluates its body in a test-comment context.

Behaves like a `let`, but returns a map where `:result` is bound to the value of the last form in `body`,
and `:values` is bound to a map from the symbols in the left hand sides of the bindings to their value.

In a `test-comment` context, behaves like a `let` that evaluates its body in a `test-comment` context.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries